@@ -279,15 +279,12 @@ def render_table(data, append_headers, append_lineno):
             )
         html.append("</colgroup>")
         append_headers(data, html)
-
         if index > 0:
             rows.append(data["rows"][0:2])
             rows.append(data["rows"][index*length:(index+1)*length])
         else :
-            rows.append(data["rows"][index*length:(index+1)*length])
-
-
-        for i, row in enumerate(rows):
+            rows.append(data["rows"][0:length])
+        for i, row in enumerate(data["rows"][index*length:(index+1)*length]):
             trow = [('<tr id="{}-{}-of-{}-for-data-{}-of-{}">').format(i, index, n,index*length,index+1*length)]
             append_lineno(trow, i)
             for cell in row:
